@@ -9,7 +9,10 @@ var CmdReload = &Cmd{
 	Name: "reload",
 	Desc: "triggers an env reload",
 	Action: actionWithConfig(func(env Env, args []string, config *Config) error {
-		foundRC := config.FindRC()
+		foundRC, err := config.FindRC()
+		if err != nil {
+			return err
+		}
 		if foundRC == nil {
 			return fmt.Errorf(".envrc not found")
 		}
