@@ -53,8 +53,8 @@ func init() {
 		CmdDump,
 		CmdEdit,
 		CmdExec,
-		CmdExpandPath,
 		CmdExport,
+		CmdFetchURL,
 		CmdHelp,
 		CmdHook,
 		CmdPrune,
