@@ -17,6 +17,7 @@ type Config struct {
 	Env             Env
 	WorkDir         string // Current directory
 	ConfDir         string
+	CacheDir        string
 	DataDir         string
 	SelfPath        string
 	BashPath        string
@@ -153,6 +154,14 @@ func LoadConfig(env Env) (config *Config, err error) {
 		}
 	}
 
+	if config.CacheDir == "" {
+		config.CacheDir = xdg.CacheDir(env, "direnv")
+	}
+	if config.CacheDir == "" {
+		err = fmt.Errorf("couldn't find a cache directory for direnv")
+		return
+	}
+
 	if config.DataDir == "" {
 		config.DataDir = xdg.DataDir(env, "direnv")
 	}
@@ -182,15 +191,29 @@ func (config *Config) LoadedRC() *RC {
 	return RCFromEnv(rcPath, timesString, config)
 }
 
+// EnvFromRC loads an RC from a specified path and returns the new environment
+func (config *Config) EnvFromRC(path string, previousEnv Env) (Env, error) {
+	rc, err := RCFromPath(path, config)
+	if err != nil {
+		return nil, err
+	}
+	return rc.Load(previousEnv)
+}
+
 // FindRC looks for a RC file in the config environment
 func (config *Config) FindRC() (*RC, error) {
 	return FindRC(config.WorkDir, config)
 }
 
-// EnvDiff returns the recorded environment diff that was stored if any.
-func (config *Config) EnvDiff() (*EnvDiff, error) {
+// Revert undoes the recorded changes (if any) to the supplied environment,
+// returning a new environment
+func (config *Config) Revert(env Env) (Env, error) {
 	if config.Env[DIRENV_DIFF] == "" {
-		return nil, nil
+		return env.Copy(), nil
 	}
-	return LoadEnvDiff(config.Env[DIRENV_DIFF])
+	diff, err := LoadEnvDiff(config.Env[DIRENV_DIFF])
+	if err == nil {
+		return diff.Reverse().Patch(env), nil
+	}
+	return nil, err
 }
