@@ -8,6 +8,10 @@ import (
 var bashPath string
 
 func main() {
+	// We drop $PWD from caller since it can include symlinks, which will
+	// break relative path access when finding .envrc in a parent.
+	_ = os.Unsetenv("PWD")
+
 	var env = GetEnv()
 	var args = os.Args
 
@@ -15,7 +19,7 @@ func main() {
 
 	err := CommandsDispatch(env, args)
 	if err != nil {
-		log_error("error %v", err)
+		logError("error %v", err)
 		os.Exit(1)
 	}
 }
